==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/FOLLOWUPTIMING_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FOLLOWUPTIMING_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FOLLOWUPTIMING_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FOLLOWUPTIMINGCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FOLLOWUPTIMING_Type", propOrder = {
    "followuptimingcode",
    "description"
})
public class FOLLOWUPTIMING_Type {

    @XmlElement(name = "FOLLOWUPTIMINGCODE", required = true)
    protected String followuptimingcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété followuptimingcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFOLLOWUPTIMINGCODE() {
        return followuptimingcode;
    }

    /**
     * Définit la valeur de la propriété followuptimingcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFOLLOWUPTIMINGCODE(String value) {
        this.followuptimingcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/FOLLOWUPTIMING_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FOLLOWUPTIMING_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FOLLOWUPTIMING_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FOLLOWUPTIMINGCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FOLLOWUPTIMING_Type", propOrder = {
    "followuptimingcode",
    "description"
})
public class FOLLOWUPTIMING_Type {

    @XmlElement(name = "FOLLOWUPTIMINGCODE", required = true)
    protected String followuptimingcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the followuptimingcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFOLLOWUPTIMINGCODE() {
        return followuptimingcode;
    }

    /**
     * Sets the value of the followuptimingcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFOLLOWUPTIMINGCODE(String value) {
        this.followuptimingcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
